@@ -1,6 +1,7 @@
 #' compute CV for each row in matrix
 #' 
 #' Typically used to create and violin plot
+#' 
 #' @param data matrix
 #' @param top remove top (default 30) CV
 #' @param na.rm default TRUE
@@ -12,10 +13,14 @@
 #' length(cv)
 #' stopifnot(length(cv) == 45)
 #' hist(cv)
+#' 
 CV <- function(data, top = 30, na.rm = TRUE){
+  # TODO review code - there might to many checks and filters for NA
+  idx <- apply(data,1, function(x){(ncol(data) - sum(is.na(x))) >= 2 })
+  data <- data[idx,]
   sd = apply(data, 1, sd, na.rm = na.rm)
   mean = apply(data, 1, mean, na.rm = na.rm)
-  idx <- mean==0
+  idx <- mean==0 | is.na(mean)
   sd <- sd[!idx]
   mean <- mean[!idx]
   res = sd/mean * 100
