@@ -1,7 +1,7 @@
 #'Streamline descriptive analysis of quantitative data matrices
 #'@name quantable
 #'@docType package
-#'@import RColorBrewer scales gplots e1071
+#'@import RColorBrewer e1071
 #'@importFrom grDevices dev.off heat.colors
 #'@importFrom graphics abline axis image layout lines pairs plot points text
 #'@importFrom stats cor.test dist hclust mad median p.adjust qqplot runmed t.test
@@ -10,4 +10,14 @@
 NULL
 # hack to supress _no visible binding for global variable _ warning in R CMD check.
 utils::globalVariables(c("ratio"), add = TRUE)
-print("loading package quantable")
+
+.onAttach <- function(libname, pkgname) {
+  packageStartupMessage("loading package quantable")
+}
+
+
+#' example data from multigroup analysis
+#' @name multigroupFCDATA
+#' @docType data
+NULL
+
